@@ -1,9 +1,9 @@
 package DBIx::Class::Schema::AuditLog::Structure::Changeset;
 {
-  $DBIx::Class::Schema::AuditLog::Structure::Changeset::VERSION = '0.2.5';
+  $DBIx::Class::Schema::AuditLog::Structure::Changeset::VERSION = '0.2.6';
 }
 
-use base 'DBIx::Class::Core';
+use base 'DBIx::Class::Schema::AuditLog::Structure::Base';
 
 use strict;
 use warnings;
@@ -59,7 +59,7 @@ DBIx::Class::Schema::AuditLog::Structure::Changeset
 
 =head1 VERSION
 
-version 0.2.5
+version 0.2.6
 
 =head1 AUTHOR
 
