@@ -1,9 +1,9 @@
 package DBIx::Class::Schema::AuditLog::Structure::User;
 {
-  $DBIx::Class::Schema::AuditLog::Structure::User::VERSION = '0.2.5';
+  $DBIx::Class::Schema::AuditLog::Structure::User::VERSION = '0.2.6';
 }
 
-use base 'DBIx::Class::Core';
+use base 'DBIx::Class::Schema::AuditLog::Structure::Base';
 
 use strict;
 use warnings;
@@ -44,7 +44,7 @@ DBIx::Class::Schema::AuditLog::Structure::User
 
 =head1 VERSION
 
-version 0.2.5
+version 0.2.6
 
 =head1 AUTHOR
 
